@@ -149,6 +149,9 @@ def from_special(uri, handle):
     content_type = handle.headers.type
     data = handle.read()
 
+    if content_type.startswith('text/'):
+        data = data.decode('utf-8', 'ignore')
+
     tiddler = Tiddler(title)
     tiddler.type = content_type
     tiddler.text = data
@@ -283,11 +286,7 @@ def _get_tiddler_from_div(node):
     Create a Tiddler from an HTML div element.
     """
     tiddler = Tiddler(node.getAttribute('title'))
-    try:
-        tiddler.text = _html_decode(_get_text(node.getElementsByTagName('pre')))
-    except IndexError:
-        # there are no contents in the tiddler
-        tiddler.text = ''
+    tiddler.text = _html_decode(_get_text(node.getElementsByTagName('pre')))
 
     for attr, value in node.attributes.items():
         data = value
